@@ -44,13 +44,11 @@ namespace KontactInterface
 {
 class SummaryMimeData : public QMimeData
 {
+    Q_OBJECT
 public:
     bool hasFormat(const QString &format) const Q_DECL_OVERRIDE
     {
-        if (format == QLatin1String("application/x-kontact-summary")) {
-            return true;
-        }
-        return false;
+        return format == QLatin1String("application/x-kontact-summary");
     }
 };
 }
@@ -180,3 +178,4 @@ void Summary::dropEvent(QDropEvent *event)
     emit summaryWidgetDropped(this, event->source(), alignment);
 }
 
+#include <summary.moc>
